from .general_prompts import query_table_overview, summarize_column, groupby_analysis, trend_analysis, outlier_analysis

__all__ = [query_table_overview, summarize_column, groupby_analysis, trend_analysis, outlier_analysis]